scipy.sparse.linalg
===================

.. automodule:: scipy.sparse.linalg

   
   
   .. rubric:: Functions

   .. autosummary::
   
      aslinearoperator
      bicg
      bicgstab
      cg
      cgs
      eigs
      eigsh
      factorized
      gmres
      isspmatrix
      lgmres
      lobpcg
      lsqr
      minres
      qmr
      spilu
      splu
      spsolve
      svds
      use_solver
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
   
      LinearOperator
      Tester
      csc_matrix
      csr_matrix
   
   

   
   
   .. rubric:: Exceptions

   .. autosummary::
   
      ArpackError
      ArpackNoConvergence
   
   